@@ -3,7 +3,7 @@ package Mail::Toaster;
 use strict;
 use warnings;
 
-our $VERSION = '5.50';
+our $VERSION = '5.51';
 
 use Carp;
 use Cwd;
@@ -90,7 +90,6 @@ sub check_running_processes {
 
     my @processes = qw/ svscan qmail-send multilog /;
 
-    push @processes, "httpd"              if $conf->{install_apache};
     push @processes, "lighttpd"           if $conf->{install_lighttpd};
     push @processes, "mysqld"             if $conf->{install_mysqld};
     push @processes, "snmpd"              if $conf->{install_snmp};
@@ -381,8 +380,7 @@ sub maildir_clean_ham {
 }
 
 sub get_daemons {
-    my $self = shift;
-    my $active = shift;
+    my ($self, $active) = @_;
     return qw/ smtp send pop3 submit qmail-deliverable qpsmtpd vpopmaild / if ! $active;
 
     my @list = qw/ send pop3 /;
@@ -705,6 +703,8 @@ sub service_symlinks_smtp {
 
 sub service_symlinks_submit {
     my $self = shift;
+    $self->conf->{submit_enable} or return;
+
     my $daemon = $self->conf->{submit_daemon} or return 'submit';
 
     if ( $daemon eq 'qpsmtpd' ) {
@@ -1137,9 +1137,10 @@ sub supervised_tcpserver_cdb {
     return "\\\n\t-x $cdb ";
 };
 
+sub version { $VERSION; }
+
 1;
 __END__
-sub {}
 
 =head1 NAME
 
